@@ -28,7 +28,9 @@ from magnum.common import short_id
 from magnum.conductor.handlers import ca_conductor
 from magnum.conductor.handlers import cluster_conductor
 from magnum.conductor.handlers import conductor_listener
+from magnum.conductor.handlers import federation_conductor
 from magnum.conductor.handlers import indirection_api
+from magnum.conductor.handlers import nodegroup_conductor
 import magnum.conf
 from magnum import version
 
@@ -51,6 +53,8 @@ def main():
         cluster_conductor.Handler(),
         conductor_listener.Handler(),
         ca_conductor.Handler(),
+        federation_conductor.Handler(),
+        nodegroup_conductor.Handler(),
     ]
 
     server = rpc_service.Service.create(CONF.conductor.topic,
@@ -60,4 +64,12 @@ def main():
     if not workers:
         workers = processutils.get_worker_count()
     launcher = service.launch(CONF, server, workers=workers)
+
+    # NOTE(mnaser): We create the periodic tasks here so that they
+    #               can be attached to the main process and not
+    #               duplicated in all the children if multiple
+    #               workers are being used.
+    server.create_periodic_tasks()
+    server.start()
+
     launcher.wait()
