@@ -22,6 +22,17 @@ kubernetes_opts = [
                     'Keystone auth policy for Kubernetes cluster when '
                     'the Keystone auth is enabled. Vendors can put their '
                     'specific default policy here'),
+    cfg.StrOpt('post_install_manifest_url',
+               default="",
+               help='An URL of the manifest file will be installed after '
+                    'the Kubernetes cluster created. For exmaple, this '
+                    'could be a file including the vendor specific '
+                    'storage class.'),
+    cfg.IntOpt('health_polling_interval',
+               default=60,
+               help=('The default polling interval for Kubernetes cluster '
+                     'health. If this number is negative the periodic task '
+                     'will be disabled.')),
 ]
 
 
