@@ -19,7 +19,6 @@ import abc
 
 from oslo_config import cfg
 from oslo_db import api as db_api
-import six
 
 from magnum.common import profiler
 
@@ -35,8 +34,7 @@ def get_instance():
 
 
 @profiler.trace_cls("db")
-@six.add_metaclass(abc.ABCMeta)
-class Connection(object):
+class Connection(object, metaclass=abc.ABCMeta):
     """Base class for storage system connections."""
 
     @abc.abstractmethod
@@ -634,7 +632,7 @@ class Connection(object):
 
         :param context: The security context
         :param cluster_id: The uuid of the cluster where the nodegroup
-                             belongs to.
+                           belongs to.
         :param filters: Filters to apply. Defaults to None.
 
         :param limit: Maximum number of nodegroups to return.
