@@ -13,7 +13,6 @@
 # under the License.
 
 """SQLAlchemy storage backend."""
-import six
 
 from oslo_db import exception as db_exc
 from oslo_db.sqlalchemy import session as db_session
@@ -344,7 +343,7 @@ class Connection(api.Connection):
         query = self._add_tenant_filters(context, query)
         public_q = model_query(models.ClusterTemplate).filter_by(public=True)
         query = query.union(public_q)
-        query = query.filter(models.ClusterTemplate.id==cluster_template_id)
+        query = query.filter(models.ClusterTemplate.id == cluster_template_id)
         try:
             return query.one()
         except NoResultFound:
@@ -356,7 +355,8 @@ class Connection(api.Connection):
         query = self._add_tenant_filters(context, query)
         public_q = model_query(models.ClusterTemplate).filter_by(public=True)
         query = query.union(public_q)
-        query = query.filter(models.ClusterTemplate.uuid==cluster_template_uuid)
+        query = query.filter(
+                models.ClusterTemplate.uuid == cluster_template_uuid)
         try:
             return query.one()
         except NoResultFound:
@@ -368,7 +368,8 @@ class Connection(api.Connection):
         query = self._add_tenant_filters(context, query)
         public_q = model_query(models.ClusterTemplate).filter_by(public=True)
         query = query.union(public_q)
-        query = query.filter(models.ClusterTemplate.name==cluster_template_name)
+        query = query.filter(
+                models.ClusterTemplate.name == cluster_template_name)
         try:
             return query.one()
         except MultipleResultsFound:
@@ -436,7 +437,7 @@ class Connection(api.Connection):
                 # NOTE(flwang): We only allow to update ClusterTemplate to be
                 # public, hidden and rename
                 if (not self._is_publishing_cluster_template(values) and
-                        list(six.viewkeys(values)) != ["name"]):
+                        list(values.keys()) != ["name"]):
                     raise exception.ClusterTemplateReferenced(
                         clustertemplate=cluster_template_id)
 
