@@ -112,6 +112,9 @@ KUBEAPI_OPTIONS="$KUBEAPI_OPTIONS"
 KUBEPROXY_OPTIONS="$KUBEPROXY_OPTIONS"
 KUBESCHEDULER_OPTIONS="$KUBESCHEDULER_OPTIONS"
 OCTAVIA_ENABLED="$OCTAVIA_ENABLED"
+OCTAVIA_PROVIDER="$OCTAVIA_PROVIDER"
+OCTAVIA_LB_ALGORITHM="$OCTAVIA_LB_ALGORITHM"
+OCTAVIA_LB_HEALTHCHECK="$OCTAVIA_LB_HEALTHCHECK"
 KUBE_SERVICE_ACCOUNT_KEY="$KUBE_SERVICE_ACCOUNT_KEY"
 KUBE_SERVICE_ACCOUNT_PRIVATE_KEY="$KUBE_SERVICE_ACCOUNT_PRIVATE_KEY"
 PROMETHEUS_TAG="$PROMETHEUS_TAG"
@@ -121,9 +124,6 @@ KEYSTONE_AUTH_ENABLED="$KEYSTONE_AUTH_ENABLED"
 K8S_KEYSTONE_AUTH_TAG="$K8S_KEYSTONE_AUTH_TAG"
 PROJECT_ID="$PROJECT_ID"
 EXTERNAL_NETWORK_ID="$EXTERNAL_NETWORK_ID"
-TILLER_ENABLED="$TILLER_ENABLED"
-TILLER_TAG="$TILLER_TAG"
-TILLER_NAMESPACE="$TILLER_NAMESPACE"
 HELM_CLIENT_URL="$HELM_CLIENT_URL"
 HELM_CLIENT_SHA256="$HELM_CLIENT_SHA256"
 HELM_CLIENT_TAG="$HELM_CLIENT_TAG"
@@ -140,6 +140,7 @@ CSI_PROVISIONER_TAG="$CSI_PROVISIONER_TAG"
 CSI_SNAPSHOTTER_TAG="$CSI_SNAPSHOTTER_TAG"
 CSI_RESIZER_TAG="$CSI_RESIZER_TAG"
 CSI_NODE_DRIVER_REGISTRAR_TAG="$CSI_NODE_DRIVER_REGISTRAR_TAG"
+CSI_LIVENESS_PROBE_TAG="$CSI_LIVENESS_PROBE_TAG"
 DRAINO_TAG="$DRAINO_TAG"
 MAGNUM_AUTO_HEALER_TAG="$MAGNUM_AUTO_HEALER_TAG"
 AUTOSCALER_TAG="$AUTOSCALER_TAG"
