@@ -12,11 +12,11 @@
 
 import datetime
 from unittest import mock
+from urllib import parse as urlparse
 
 from oslo_config import cfg
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
-from six.moves.urllib import parse as urlparse
 from webtest.app import AppError
 from wsme import types as wtypes
 
@@ -262,10 +262,10 @@ class TestPatch(api_base.FunctionalTest):
             master_flavor_id='m1.magnum',
             external_network_id='public',
             keypair_id='test',
-            volume_driver='rexray',
+            volume_driver='cinder',
             public=False,
             docker_volume_size=20,
-            coe='swarm',
+            coe='kubernetes',
             labels={'key1': 'val1', 'key2': 'val2'},
             hidden=False
         )
@@ -641,7 +641,7 @@ class TestPost(api_base.FunctionalTest):
         test_time = datetime.datetime(2000, 1, 1, 0, 0)
         mock_utcnow.return_value = test_time
         mock_image_data.return_value = {'name': 'mock_name',
-                                        'os_distro': 'fedora-atomic'}
+                                        'os_distro': 'fedora-coreos'}
 
         response = self.post_json('/clustertemplates', bdict)
         self.assertEqual(201, response.status_int)
@@ -663,7 +663,7 @@ class TestPost(api_base.FunctionalTest):
                 self.dbapi, 'create_cluster_template',
                 wraps=self.dbapi.create_cluster_template) as cc_mock:
             mock_image_data.return_value = {'name': 'mock_name',
-                                            'os_distro': 'fedora-atomic'}
+                                            'os_distro': 'fedora-coreos'}
             bdict = apiutils.cluster_template_post_data()
             self.post_json('/clustertemplates', bdict)
             cc_mock.assert_called_once_with(mock.ANY)
@@ -679,7 +679,7 @@ class TestPost(api_base.FunctionalTest):
                 self.dbapi, 'create_cluster_template',
                 wraps=self.dbapi.create_cluster_template) as cc_mock:
             mock_image_data.return_value = {'name': 'mock_name',
-                                            'os_distro': 'fedora-atomic'}
+                                            'os_distro': 'fedora-coreos'}
             bdict = apiutils.cluster_template_post_data(image_id='my-image')
             response = self.post_json('/clustertemplates', bdict)
             self.assertEqual(bdict['image_id'], response.json['image_id'])
@@ -695,7 +695,7 @@ class TestPost(api_base.FunctionalTest):
             mock.patch('magnum.api.attr_validator.validate_image')\
                 as mock_image_data:
             mock_image_data.return_value = {'name': 'mock_name',
-                                            'os_distro': 'fedora-atomic'}
+                                            'os_distro': 'fedora-coreos'}
             bdict = apiutils.cluster_template_post_data(**kwargs)
             self.assertRaises(AppError, self.post_json, '/clustertemplates',
                               bdict)
@@ -753,7 +753,7 @@ class TestPost(api_base.FunctionalTest):
                 self.dbapi, 'create_cluster_template',
                 wraps=self.dbapi.create_cluster_template) as cc_mock:
             mock_image_data.return_value = {'name': 'mock_name',
-                                            'os_distro': 'fedora-atomic'}
+                                            'os_distro': 'fedora-coreos'}
             bdict = apiutils.cluster_template_post_data(
                 labels={'key1': 'val1', 'key2': 'val2'})
             response = self.post_json('/clustertemplates', bdict)
@@ -769,7 +769,7 @@ class TestPost(api_base.FunctionalTest):
                 self.dbapi, 'create_cluster_template',
                 wraps=self.dbapi.create_cluster_template) as cc_mock:
             mock_image_data.return_value = {'name': 'mock_name',
-                                            'os_distro': 'fedora-atomic'}
+                                            'os_distro': 'fedora-coreos'}
             bdict = apiutils.cluster_template_post_data(docker_volume_size=99)
             response = self.post_json('/clustertemplates', bdict)
             self.assertEqual(bdict['docker_volume_size'],
@@ -783,7 +783,7 @@ class TestPost(api_base.FunctionalTest):
                 self.dbapi, 'create_cluster_template',
                 wraps=self.dbapi.create_cluster_template) as cc_mock:
             mock_image_data.return_value = {'name': 'mock_name',
-                                            'os_distro': 'fedora-atomic'}
+                                            'os_distro': 'fedora-coreos'}
             bdict = apiutils.cluster_template_post_data(
                 docker_volume_size=1, docker_storage_driver="overlay")
             note = 'deprecated in favor of overlay2'
@@ -800,9 +800,10 @@ class TestPost(api_base.FunctionalTest):
             cluster_template_dict,
             cluster_template_config_dict,
             expect_errors,
+            expect_default_driver,
             mock_image_data):
         mock_image_data.return_value = {'name': 'mock_name',
-                                        'os_distro': 'fedora-atomic'}
+                                        'os_distro': 'fedora-coreos'}
         for k, v in cluster_template_config_dict.items():
             cfg.CONF.set_override(k, v, 'cluster_template')
         with mock.patch.object(
@@ -816,10 +817,10 @@ class TestPost(api_base.FunctionalTest):
             if expect_errors:
                 self.assertEqual(400, response.status_int)
             else:
-                expected_driver = bdict.get('network_driver')
-                if not expected_driver:
-                    expected_driver = (
-                        cfg.CONF.cluster_template.swarm_default_network_driver)
+                if expect_default_driver:
+                    expected_driver = 'flannel'
+                else:
+                    expected_driver = bdict.get('network_driver')
                 self.assertEqual(expected_driver,
                                  response.json['network_driver'])
                 self.assertEqual(bdict['image_id'],
@@ -833,19 +834,23 @@ class TestPost(api_base.FunctionalTest):
                                  'network_driver': 'flannel'}
         config_dict = {}    # Default config
         expect_errors_flag = False
+        expect_default_driver_flag = False
         self._test_create_cluster_template_network_driver_attr(
             cluster_template_dict,
             config_dict,
-            expect_errors_flag)
+            expect_errors_flag,
+            expect_default_driver_flag)
 
     def test_create_cluster_template_with_no_network_driver(self):
         cluster_template_dict = {}
         config_dict = {}
         expect_errors_flag = False
+        expect_default_driver_flag = True
         self._test_create_cluster_template_network_driver_attr(
             cluster_template_dict,
             config_dict,
-            expect_errors_flag)
+            expect_errors_flag,
+            expect_default_driver_flag)
 
     def test_create_cluster_template_with_network_driver_non_def_config(self):
         cluster_template_dict = {'coe': 'kubernetes',
@@ -853,10 +858,12 @@ class TestPost(api_base.FunctionalTest):
         config_dict = {
             'kubernetes_allowed_network_drivers': ['flannel', 'foo']}
         expect_errors_flag = False
+        expect_default_driver_flag = False
         self._test_create_cluster_template_network_driver_attr(
             cluster_template_dict,
             config_dict,
-            expect_errors_flag)
+            expect_errors_flag,
+            expect_default_driver_flag)
 
     def test_create_cluster_template_with_invalid_network_driver(self):
         cluster_template_dict = {'coe': 'kubernetes',
@@ -864,10 +871,12 @@ class TestPost(api_base.FunctionalTest):
         config_dict = {
             'kubernetes_allowed_network_drivers': ['flannel', 'good_driver']}
         expect_errors_flag = True
+        expect_default_driver_flag = False
         self._test_create_cluster_template_network_driver_attr(
             cluster_template_dict,
             config_dict,
-            expect_errors_flag)
+            expect_errors_flag,
+            expect_default_driver_flag)
 
     @mock.patch('magnum.api.attr_validator.validate_image')
     def test_create_cluster_template_with_volume_driver(self,
@@ -876,8 +885,8 @@ class TestPost(api_base.FunctionalTest):
                 self.dbapi, 'create_cluster_template',
                 wraps=self.dbapi.create_cluster_template) as cc_mock:
             mock_image_data.return_value = {'name': 'mock_name',
-                                            'os_distro': 'fedora-atomic'}
-            bdict = apiutils.cluster_template_post_data(volume_driver='rexray')
+                                            'os_distro': 'fedora-coreos'}
+            bdict = apiutils.cluster_template_post_data(volume_driver='cinder')
             response = self.post_json('/clustertemplates', bdict)
             self.assertEqual(bdict['volume_driver'],
                              response.json['volume_driver'])
@@ -891,7 +900,7 @@ class TestPost(api_base.FunctionalTest):
                 self.dbapi, 'create_cluster_template',
                 wraps=self.dbapi.create_cluster_template) as cc_mock:
             mock_image_data.return_value = {'name': 'mock_name',
-                                            'os_distro': 'fedora-atomic'}
+                                            'os_distro': 'fedora-coreos'}
             bdict = apiutils.cluster_template_post_data()
             response = self.post_json('/clustertemplates', bdict)
             self.assertEqual(bdict['volume_driver'],
@@ -908,7 +917,7 @@ class TestPost(api_base.FunctionalTest):
                 wraps=self.dbapi.create_cluster_template) as cc_mock:
             mock_policy.return_value = True
             mock_image_data.return_value = {'name': 'mock_name',
-                                            'os_distro': 'fedora-atomic'}
+                                            'os_distro': 'fedora-coreos'}
             bdict = apiutils.cluster_template_post_data(public=True)
             response = self.post_json('/clustertemplates', bdict)
             self.assertTrue(response.json['public'])
@@ -928,7 +937,7 @@ class TestPost(api_base.FunctionalTest):
             # make policy enforcement fail
             mock_policy.return_value = False
             mock_image_data.return_value = {'name': 'mock_name',
-                                            'os_distro': 'fedora-atomic'}
+                                            'os_distro': 'fedora-coreos'}
             bdict = apiutils.cluster_template_post_data(public=True)
             self.assertRaises(AppError, self.post_json, '/clustertemplates',
                               bdict)
@@ -941,7 +950,7 @@ class TestPost(api_base.FunctionalTest):
                 self.dbapi, 'create_cluster_template',
                 wraps=self.dbapi.create_cluster_template) as cc_mock:
             mock_image_data.return_value = {'name': 'mock_name',
-                                            'os_distro': 'fedora-atomic'}
+                                            'os_distro': 'fedora-coreos'}
             bdict = apiutils.cluster_template_post_data(public=False)
             response = self.post_json('/clustertemplates', bdict)
             self.assertFalse(response.json['public'])
@@ -960,7 +969,7 @@ class TestPost(api_base.FunctionalTest):
                 wraps=self.dbapi.create_cluster_template) as cc_mock:
             mock_policy.return_value = True
             mock_image_data.return_value = {'name': 'mock_name',
-                                            'os_distro': 'fedora-atomic'}
+                                            'os_distro': 'fedora-coreos'}
             bdict = apiutils.cluster_template_post_data(hidden=True)
             response = self.post_json('/clustertemplates', bdict)
             self.assertTrue(response.json['hidden'])
@@ -980,7 +989,7 @@ class TestPost(api_base.FunctionalTest):
             # make policy enforcement fail
             mock_policy.return_value = False
             mock_image_data.return_value = {'name': 'mock_name',
-                                            'os_distro': 'fedora-atomic'}
+                                            'os_distro': 'fedora-coreos'}
             bdict = apiutils.cluster_template_post_data(hidden=True)
             self.assertRaises(AppError, self.post_json, '/clustertemplates',
                               bdict)
@@ -999,7 +1008,7 @@ class TestPost(api_base.FunctionalTest):
     def test_create_cluster_template_with_os_distro_image(self,
                                                           mock_image_data):
         mock_image_data.return_value = {'name': 'mock_name',
-                                        'os_distro': 'fedora-atomic'}
+                                        'os_distro': 'fedora-coreos'}
         bdict = apiutils.cluster_template_post_data()
         del bdict['uuid']
         response = self.post_json('/clustertemplates', bdict,
@@ -1010,7 +1019,7 @@ class TestPost(api_base.FunctionalTest):
     def test_create_cluster_template_with_image_name(self,
                                                      mock_image_data):
         mock_image = {'name': 'mock_name',
-                      'os_distro': 'fedora-atomic'}
+                      'os_distro': 'fedora-coreos'}
         mock_image_data.return_value = mock_image
         bdict = apiutils.cluster_template_post_data()
         del bdict['uuid']
@@ -1049,7 +1058,7 @@ class TestPost(api_base.FunctionalTest):
     def test_create_cluster_template_without_keypair_id(self,
                                                         mock_image_data):
         mock_image_data.return_value = {'name': 'mock_name',
-                                        'os_distro': 'fedora-atomic'}
+                                        'os_distro': 'fedora-coreos'}
         bdict = apiutils.cluster_template_post_data()
         del bdict['keypair_id']
         response = self.post_json('/clustertemplates', bdict)
@@ -1059,7 +1068,7 @@ class TestPost(api_base.FunctionalTest):
     def test_create_cluster_template_with_dns(self,
                                               mock_image_data):
         mock_image_data.return_value = {'name': 'mock_name',
-                                        'os_distro': 'fedora-atomic'}
+                                        'os_distro': 'fedora-coreos'}
         bdict = apiutils.cluster_template_post_data()
         response = self.post_json('/clustertemplates', bdict)
         self.assertEqual(201, response.status_int)
@@ -1071,7 +1080,7 @@ class TestPost(api_base.FunctionalTest):
                                                            mock_image_data):
         self.mock_valid_os_res.side_effect = exception.KeyPairNotFound("Test")
         mock_image_data.return_value = {'name': 'mock_name',
-                                        'os_distro': 'fedora-atomic'}
+                                        'os_distro': 'fedora-coreos'}
         bdict = apiutils.cluster_template_post_data()
         response = self.post_json('/clustertemplates', bdict,
                                   expect_errors=True)
@@ -1081,7 +1090,7 @@ class TestPost(api_base.FunctionalTest):
     def test_create_cluster_template_with_flavor(self,
                                                  mock_image_data):
         mock_image_data.return_value = {'name': 'mock_name',
-                                        'os_distro': 'fedora-atomic'}
+                                        'os_distro': 'fedora-coreos'}
         bdict = apiutils.cluster_template_post_data()
         response = self.post_json('/clustertemplates', bdict)
         self.assertEqual(201, response.status_int)
@@ -1095,7 +1104,7 @@ class TestPost(api_base.FunctionalTest):
                                                           mock_image_data):
         self.mock_valid_os_res.side_effect = exception.FlavorNotFound("flavor")
         mock_image_data.return_value = {'name': 'mock_name',
-                                        'os_distro': 'fedora-atomic'}
+                                        'os_distro': 'fedora-coreos'}
         bdict = apiutils.cluster_template_post_data()
         response = self.post_json('/clustertemplates', bdict,
                                   expect_errors=True)
@@ -1105,7 +1114,7 @@ class TestPost(api_base.FunctionalTest):
     def test_create_cluster_template_with_external_network(self,
                                                            mock_image_data):
         mock_image_data.return_value = {'name': 'mock_name',
-                                        'os_distro': 'fedora-atomic'}
+                                        'os_distro': 'fedora-coreos'}
         bdict = apiutils.cluster_template_post_data()
         response = self.post_json('/clustertemplates', bdict)
         self.assertEqual(201, response.status_int)
@@ -1118,7 +1127,7 @@ class TestPost(api_base.FunctionalTest):
         self.mock_valid_os_res.side_effect = exception.ExternalNetworkNotFound(
             "test")
         mock_image_data.return_value = {'name': 'mock_name',
-                                        'os_distro': 'fedora-atomic'}
+                                        'os_distro': 'fedora-coreos'}
         bdict = apiutils.cluster_template_post_data()
         response = self.post_json('/clustertemplates', bdict,
                                   expect_errors=True)
@@ -1129,7 +1138,7 @@ class TestPost(api_base.FunctionalTest):
         with mock.patch.object(self.dbapi, 'create_cluster_template',
                                wraps=self.dbapi.create_cluster_template):
             mock_image_data.return_value = {'name': 'mock_name',
-                                            'os_distro': 'fedora-atomic'}
+                                            'os_distro': 'fedora-coreos'}
             bdict = apiutils.cluster_template_post_data()
             bdict.pop('name')
             resp = self.post_json('/clustertemplates', bdict)
@@ -1138,9 +1147,9 @@ class TestPost(api_base.FunctionalTest):
 
     def test_create_cluster_with_disabled_driver(self):
         cfg.CONF.set_override('disabled_drivers',
-                              ['swarm_fedora_atomic_v1'],
+                              ['kubernetes'],
                               group='drivers')
-        bdict = apiutils.cluster_template_post_data(coe="swarm")
+        bdict = apiutils.cluster_template_post_data(coe="kubernetes")
         self.assertRaises(AppError, self.post_json, '/clustertemplates',
                           bdict)
 
@@ -1153,7 +1162,7 @@ class TestPost(api_base.FunctionalTest):
         test_time = datetime.datetime(2000, 1, 1, 0, 0)
         mock_utcnow.return_value = test_time
         mock_image_data.return_value = {'name': 'mock_name',
-                                        'os_distro': 'fedora-atomic'}
+                                        'os_distro': 'fedora-coreos'}
 
         response = self.post_json('/clustertemplates', bdict)
         self.assertEqual(201, response.status_int)
@@ -1168,6 +1177,18 @@ class TestPost(api_base.FunctionalTest):
             response.json['created_at']).replace(tzinfo=None)
         self.assertEqual(test_time, return_created_at)
 
+    @mock.patch('magnum.api.attr_validator.validate_image')
+    def test_create_cluster_template_with_driver_name(self, mock_image_data):
+        mock_image = {'name': 'mock_name',
+                      'os_distro': 'fedora-coreos',
+                      'magnum_driver': 'mock_driver'}
+        mock_image_data.return_value = mock_image
+        bdict = apiutils.cluster_template_post_data()
+        resp = self.post_json('/clustertemplates', bdict)
+        self.assertEqual(201, resp.status_int)
+        self.assertEqual(resp.json['driver'],
+                         mock_image.get('magnum_driver'))
+
 
 class TestDelete(api_base.FunctionalTest):
 
