@@ -13,7 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
+
 import oslo_messaging as messaging
 from oslo_messaging.rpc import dispatcher
 from oslo_serialization import jsonutils
@@ -25,29 +26,51 @@ from magnum.tests import base
 
 class TestRpc(base.TestCase):
     @mock.patch.object(rpc, 'profiler', None)
-    @mock.patch.object(messaging, 'RPCClient')
-    def test_get_client(self, mock_client):
+    @mock.patch.object(rpc, 'RequestContextSerializer')
+    @mock.patch.object(messaging, 'get_rpc_client')
+    def test_get_client(self, mock_get, mock_ser):
         rpc.TRANSPORT = mock.Mock()
         tgt = mock.Mock()
         ser = mock.Mock()
-        mock_client.return_value = 'client'
+        mock_get.return_value = 'client'
+        mock_ser.return_value = ser
 
         client = rpc.get_client(tgt, version_cap='1.0', serializer=ser,
                                 timeout=6969)
 
-        mock_client.assert_called_once_with(rpc.TRANSPORT,
-                                            tgt, version_cap='1.0',
-                                            serializer=ser, timeout=6969)
+        mock_get.assert_called_once_with(rpc.TRANSPORT,
+                                         tgt, version_cap='1.0',
+                                         serializer=ser, timeout=6969)
+        self.assertEqual('client', client)
+
+    @mock.patch.object(rpc, 'profiler', mock.Mock())
+    @mock.patch.object(rpc, 'ProfilerRequestContextSerializer')
+    @mock.patch.object(messaging, 'get_rpc_client')
+    def test_get_client_profiler_enabled(self, mock_get, mock_ser):
+        rpc.TRANSPORT = mock.Mock()
+        tgt = mock.Mock()
+        ser = mock.Mock()
+        mock_get.return_value = 'client'
+        mock_ser.return_value = ser
+
+        client = rpc.get_client(tgt, version_cap='1.0', serializer=ser,
+                                timeout=6969)
+
+        mock_get.assert_called_once_with(rpc.TRANSPORT,
+                                         tgt, version_cap='1.0',
+                                         serializer=ser, timeout=6969)
         self.assertEqual('client', client)
 
     @mock.patch.object(rpc, 'profiler', None)
+    @mock.patch.object(rpc, 'RequestContextSerializer')
     @mock.patch.object(messaging, 'get_rpc_server')
-    def test_get_server(self, mock_get):
+    def test_get_server(self, mock_get, mock_ser):
         rpc.TRANSPORT = mock.Mock()
         ser = mock.Mock()
         tgt = mock.Mock()
         ends = mock.Mock()
         mock_get.return_value = 'server'
+        mock_ser.return_value = ser
         access_policy = dispatcher.DefaultRPCAccessPolicy
         server = rpc.get_server(tgt, ends, serializer=ser)
 
@@ -56,6 +79,25 @@ class TestRpc(base.TestCase):
                                          access_policy=access_policy)
         self.assertEqual('server', server)
 
+    @mock.patch.object(rpc, 'profiler', mock.Mock())
+    @mock.patch.object(rpc, 'ProfilerRequestContextSerializer')
+    @mock.patch.object(messaging, 'get_rpc_server')
+    def test_get_server_profiler_enabled(self, mock_get, mock_ser):
+        rpc.TRANSPORT = mock.Mock()
+        ser = mock.Mock()
+        tgt = mock.Mock()
+        ends = mock.Mock()
+        mock_ser.return_value = ser
+        mock_get.return_value = 'server'
+        access_policy = dispatcher.DefaultRPCAccessPolicy
+        server = rpc.get_server(tgt, ends, serializer='foo')
+
+        mock_ser.assert_called_once_with('foo')
+        mock_get.assert_called_once_with(rpc.TRANSPORT, tgt, ends,
+                                         executor='eventlet', serializer=ser,
+                                         access_policy=access_policy)
+        self.assertEqual('server', server)
+
     @mock.patch.object(messaging, 'TransportURL')
     def test_get_transport_url(self, mock_url):
         conf = mock.Mock()
